@@ -65,6 +65,15 @@ seafile_generate_magic (int version, const char *repo_id,
                         const char *passwd,
                         char *magic);
 
+void
+seafile_generate_pwd_hash (int version,
+                           const char *repo_id,
+                           const char *passwd,
+                           const char *repo_salt,
+                           const char *algo,
+                           const char *params_str,
+                           char *pwd_hash);
+
 int
 seafile_verify_repo_passwd (const char *repo_id,
                             const char *passwd,
@@ -72,6 +81,15 @@ seafile_verify_repo_passwd (const char *repo_id,
                             int version,
                             const char *repo_salt);
 
+int
+seafile_pwd_hash_verify_repo_passwd (int version,
+                                     const char *repo_id,
+                                     const char *passwd,
+                                     const char *repo_salt,
+                                     const char *pwd_hash,
+                                     const char *algo,
+                                     const char *params_str);
+
 int
 seafile_decrypt_repo_enc_key (int enc_version,
                               const char *passwd, const char *random_key,
