@@ -26,6 +26,8 @@
 #define REPO_PROP_SYNC_INTERVAL "sync-interval"
 #define REPO_SYNC_WORKTREE_NAME "sync-worktree-name"
 #define REPO_PROP_USERNAME "username"
+#define REPO_PROP_EMPTY_ENC_KEY "empty-enc-key"
+#define REPO_PROP_CHECK_BLOCKS "check-blocks"
 
 struct _SeafRepoManager;
 typedef struct _SeafRepo SeafRepo;
@@ -105,6 +107,9 @@ struct _SeafRepo {
 
     /* Non-zero if periodic sync is set for this repo. */
     int sync_interval;
+
+    // empty_enc_key will be set to true when the currently loadded enc key is empty, or when blocks can be decrypted using an empty enc key.
+    gboolean empty_enc_key;
 };
 
 
