@@ -50,9 +50,16 @@
 
 #ifndef WIN32
 #include <utime.h>
+#endif
+
+#if defined __linux__ || defined __APPLE__
 #include <sys/xattr.h>
 #endif
 
+#if defined __FreeBSD__ || defined __NetBSD__
+#include <sys/extattr.h>
+#endif
+
 #include <zlib.h>
 
 #include "log.h"
@@ -799,6 +806,13 @@ should_ignore_on_checkout (const char *file_path, IgnoreReason *ignore_reason)
     for (; j < n_comps; ++j) {
         file_name = components[j];
 
+        if (g_strcmp0(file_name, ".") == 0 || g_strcmp0(file_name, "..") == 0) {
+            if (ignore_reason)
+                *ignore_reason = IGNORE_REASON_INVALID_CHARACTER;
+            ret = TRUE;
+            goto out;
+        }
+
         if (has_trailing_space_or_period (file_name)) {
             /* Ignore files/dir whose path has trailing spaces. It would cause
              * problem on windows. */
@@ -830,9 +844,25 @@ should_ignore_on_checkout (const char *file_path, IgnoreReason *ignore_reason)
 
 out:
     g_strfreev (components);
-#endif
-
     return ret;
+#else
+    char **components = g_strsplit (file_path, "/", -1);
+    int n_comps = g_strv_length (components);
+    int j = 0;
+    char *file_name;
+
+    for (; j < n_comps; ++j) {
+        file_name = components[j];
+        if (g_strcmp0(file_name, ".") == 0 || g_strcmp0(file_name, "..") == 0) {
+            ret = TRUE;
+            if (ignore_reason)
+                *ignore_reason = IGNORE_REASON_INVALID_CHARACTER;
+            break;
+        }
+    }
+    g_strfreev (components);
+    return ret;
+#endif
 }
 
 ssize_t						/* Read "n" bytes from a descriptor. */
@@ -2604,6 +2634,10 @@ case_conflict_recursive (const char *worktree, const char *path, char **conflict
     if (seaf_stat (full_path, &st) < 0) {
         char *sub_path = g_path_get_dirname (path);
         ret = case_conflict_recursive (worktree, sub_path, conflict_path, no_case_conflict_hash);
+        if (!ret) {
+            no_conflict_path = g_strdup (sub_path);
+            g_hash_table_insert (no_case_conflict_hash, no_conflict_path, no_conflict_path);
+        }
         g_free (sub_path);
         goto out;
     }
@@ -2615,26 +2649,19 @@ case_conflict_recursive (const char *worktree, const char *path, char **conflict
         seaf_warning ("Checkinng path case, FindFirstFile failed %s: %lu.\n", full_path, GetLastError());
         goto out;
     }
-    char *real_path = g_utf16_to_utf8 (fdata.cFileName, -1, NULL, NULL, NULL);
-    int offset = strlen (real_path) - strlen(path);
-    if (strcasecmp (real_path + offset, path) == 0 &&
-        strcmp (real_path + offset, path) != 0) {
+    char *real_name = g_utf16_to_utf8 (fdata.cFileName, -1, NULL, NULL, NULL);
+    int offset = strlen (path) - strlen(real_name);
+    if (strcasecmp (path + offset, real_name) == 0 &&
+        strcmp (path + offset, real_name) != 0) {
         if (conflict_path) {
             *conflict_path = g_strdup(path);
         }
         ret = TRUE;
-        g_free (real_path);
-        FindClose (handle);
-        goto out;
-    } else if (strcmp (real_path + offset, path) == 0) {
-        no_conflict_path = g_strdup (path);
-        g_hash_table_insert (no_case_conflict_hash, no_conflict_path, no_conflict_path);
-
-        g_free (real_path);
+        g_free (real_name);
         FindClose (handle);
         goto out;
     }
-    g_free (real_path);
+    g_free (real_name);
     FindClose (handle);
 
     char *sub_path = g_path_get_dirname (path);
@@ -2662,6 +2689,10 @@ is_path_case_conflict (const char *worktree, const char *path, char **conflict_p
     }
     if (case_conflict_recursive (worktree, path, conflict_path, no_case_conflict_hash))
         return TRUE;
+#ifdef WIN32
+    char *no_conflict_path = g_strdup (path);
+    g_hash_table_insert (no_case_conflict_hash, no_conflict_path, no_conflict_path);
+#endif
     return FALSE;
 }
 
@@ -2724,6 +2755,12 @@ out:
 #ifdef __APPLE__
     return getxattr (path, name, value, size, 0, 0);
 #endif
+
+#if defined __FreeBSD__ || defined __NetBSD__
+    return extattr_get_file (path, EXTATTR_NAMESPACE_USER, name, value, size);
+#endif
+
+    return -1;
 }
 
 int
@@ -2772,6 +2809,12 @@ out:
 #ifdef __APPLE__
     return setxattr (path, name, value, size, 0, 0);
 #endif
+
+#if defined __FreeBSD__ || defined __NetBSD__
+    return extattr_set_file (path, EXTATTR_NAMESPACE_USER, name, value, size);
+#endif
+
+    return -1;
 }
 
 int
